@@ -36,37 +36,44 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '15.3.5.3.js';
+gTestfile = '15.3.3.1-3.js';
 
 /**
-   File Name:          15.3.5.3.js
-   ECMA Section:       Function.arguments
-   Description:
+   File Name:          15.3.3.1-3.js
+   ECMA Section:       15.3.3.1 Properties of the Function Constructor
+   Function.prototype
 
-   The value of the arguments property is normally null if there is no
-   outstanding invocation of the function in progress (that is, the
-   function has been called but has not yet returned). When a non-internal
-   Function object (15.3.2.1) is invoked, its arguments property is
-   "dynamically bound" to a newly created object that contains the arguments
-   on which it was invoked (see 10.1.6 and 10.1.8). Note that the use of this
-   property is discouraged; it is provided principally for compatibility
-   with existing old code.
+   Description:        The initial value of Function.prototype is the built-in
+   Function prototype object.
 
-   See sections 10.1.6 and 10.1.8 for more extensive tests.
+   This property shall have the attributes [DontEnum |
+   DontDelete | ReadOnly]
+
+   This test the DontDelete property of Function.prototype.
 
    Author:             christine@netscape.com
-   Date:               12 november 1997
-*/
+   Date:               28 october 1997
 
-var SECTION = "15.3.5.3";
+*/
+var SECTION = "15.3.3.1-3";
 var VERSION = "ECMA_1";
 startTest();
-var TITLE   = "Function.arguments";
+var TITLE   = "Function.prototype";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-var MYFUNCTION = new Function( "return this.arguments" );
 
-new TestCase( SECTION,  "var MYFUNCTION = new Function( 'return this.arguments' ); MYFUNCTION.arguments",   null,   MYFUNCTION.arguments );
+var FUN_PROTO = Function.prototype;
 
+new TestCase(   SECTION,
+		"delete Function.prototype",
+		false,
+		delete Function.prototype
+  );
+
+new TestCase(   SECTION,
+		"delete Function.prototype; Function.prototype",
+		FUN_PROTO,
+		eval("delete Function.prototype; Function.prototype")
+  );
 test();
