@@ -36,58 +36,31 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '7.7.3-2.js';
+gTestfile = '7.3-11.js';
 
 /**
-   File Name:          7.7.3-2.js
-   ECMA Section:       7.7.3 Numeric Literals
-
+   File Name:          7.3-11.js
+   ECMA Section:       7.3 Comments
    Description:
 
-   This is a regression test for
-   http://scopus.mcom.com/bugsplat/show_bug.cgi?id=122884
-
-   Waldemar's comments:
-
-   A numeric literal that starts with either '08' or '09' is interpreted as a
-   decimal literal; it should be an error instead.  (Strictly speaking, according
-   to ECMA v1 such literals should be interpreted as two integers -- a zero
-   followed by a decimal number whose first digit is 8 or 9, but this is a bug in
-   ECMA that will be fixed in v2.  In any case, there is no place in the grammar
-   where two consecutive numbers would be legal.)
 
    Author:             christine@netscape.com
-   Date:               15 june 1998
+   Date:               12 november 1997
 
 */
-var SECTION = "7.7.3-2";
+var SECTION = "7.3-11";
 var VERSION = "ECMA_1";
-var TITLE   = "Numeric Literals";
-var BUGNUMBER="122884";
-
 startTest();
+var TITLE   = "Comments";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-new TestCase( SECTION,
-	      "9",
-	      9,
-	      9 );
 
-new TestCase( SECTION,
-	      "09",
-	      9,
-	      09 );
+var testcase =  new TestCase( SECTION,
+			      "code following multiline comment",
+			      "pass",
+			      "pass");
 
-new TestCase( SECTION,
-	      "099",
-	      99,
-	      099 );
-
-
-new TestCase( SECTION,
-	      "077",
-	      63,
-	      077 );
+////testcase.actual="fail";
 
 test();
