@@ -36,10 +36,10 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-gTestfile = '7.5-4-n.js';
+gTestfile = '7.5-8-n.js';
 
 /**
-   File Name:          7.5-4-n.js
+   File Name:          7.5-8-n.js
    ECMA Section:       7.5 Identifiers
    Description:        Identifiers are of unlimited length
    - can contain letters, a decimal digit, _, or $
@@ -49,16 +49,16 @@ gTestfile = '7.5-4-n.js';
    Author:             christine@netscape.com
    Date:               11 september 1997
 */
-var SECTION = "7.5-4-n";
+var SECTION = "7.5-8-n";
 var VERSION = "ECMA_1";
 startTest();
 var TITLE   = "Identifiers";
 
 writeHeaderToLog( SECTION + " "+ TITLE);
 
-DESCRIPTION = "var 2abc";
+DESCRIPTION = "var @0abc = 5; @0abc";
 EXPECTED = "error";
 
-new TestCase( SECTION,    "var 2abc",   "error",    eval("var 2abc") );
+new TestCase( SECTION,    "var @0abc = 5; @0abc",   "error",    eval("var @0abc = 5; @0abc") );
 
 test();
